PRO merid, SALT = salt, PS = ps
@common
; -------------------------------------------------------------------- 
;
;  Plot meridional heat/salt transports from ORCA diaznl netcdf outputs
;
;  Keywords :
;   
;     SALT : for salt transports [default = heat transport]
;     PS   : output is postscript
;
;
;                                    E. Guilyardi - LODYC - 17/3/99
; -------------------------------------------------------------------- 
;
; 0. inits
; ==========
;
; file name + input directory
file_name = 'ST4_20y_06_25_diaznl.nc'
ncdf_db = '/workdir/rech/eee/reee066/'
out_ps = '/u/rech/eee/reee066/'
;
; Choose type of plot : h[eat] or s[alt]
;
if keyword_set(SALT) EQ 0 THEN type = 'h'
IF keyword_set(SALT) EQ 1 THEN type = 's'
;
; variables to read
;
var_name1 = 'sozonf'+type+'o'       ; overturning
var_name2 = 'sozonf'+type+'g'       ; gyre
var_name3 = 'sozonf'+type+'d'       ; diffusive
var_name4 = 'sozonf'+type+'a'       ; advective (o+g)

var_name5 = 'sozanf'+type+'o'       ; 
var_name6 = 'sozanf'+type+'g'       ; idem atlantic only
var_name7 = 'sozanf'+type+'d'       ; 
var_name8 = 'sozanf'+type+'a'       ; 

;
; 1. open and read netcdf file
; =============================
; 
cdfid=ncdf_open(ncdf_db+file_name) 

ncdf_varget, cdfid, ncdf_varid(cdfid,var_name1), field1
ncdf_varget, cdfid, ncdf_varid(cdfid,var_name2), field2
ncdf_varget, cdfid, ncdf_varid(cdfid,var_name3), field3
ncdf_varget, cdfid, ncdf_varid(cdfid,var_name4), field4
ncdf_varget, cdfid, ncdf_varid(cdfid,var_name5), field5
ncdf_varget, cdfid, ncdf_varid(cdfid,var_name6), field6
ncdf_varget, cdfid, ncdf_varid(cdfid,var_name7), field7
ncdf_varget, cdfid, ncdf_varid(cdfid,var_name8), field8

ncdf_varget, cdfid, ncdf_varid(cdfid,'nav_lat'), latitude

ncdf_close, cdfid
;
; Compute indopac/atlantic index
;
 index = where(latitude GE -36.2962)
;
; 2. make plot
; =============
; window or postscript
IF keyword_set(ps) THEN BEGIN
   reinitplt, /z,/invert
   openps
ENDIF  ELSE BEGIN 
   set_plot,'x'
   window, 0, xsize = 640, ysize = 790
   erase
ENDELSE  
; 
; organize multi-window plot
;
!p.multi = [4, 2, 2]
; margins
!x.omargin = [6, 6]
!y.omargin = [4, 8]
!x.margin = [6, 2]
!y.margin = [4, 2]

; X-axis attributes (sin of latitude plot)

latitude = sin(latitude*!pi/180.)
!p.font = 1
device,  set_font = 'Helvetica', /TT_FONT
!x.title = 'S           Latitude           N'
!x.range = [-1, 1]
!x.style = 1
!x.ticks = 8
!x.minor = 0
!x.tickv = sin([-90, -60, -30, -15, 0, 15, 30, 60, 90]*!pi/180.)
!x.tickname = ['90', '60', '30','15', '0', '15','30','60', '90']

; Y-axis attributes 
IF type EQ 'h' THEN BEGIN 

   !y.title = 'PW'
   !y.range = [-2, 3]
   !y.style = 1
   !y.minor = 5
   ymult = 1.e-15
   title = 'Heat Transport'

ENDIF  ELSE BEGIN

   !y.title = '10!E6!N Kg/s'
   !y.range = [-100, 100]
   !y.style = 1
   !y.minor = 5
   ymult = 1.e-6
   title = 'Salt Transport'

ENDELSE 

; Main plot title
xyouts, 0.5, 0.95, title, /normal, charsize = 1.5, alignment = 0.5
xyouts, 0.5, 0.92, file_name, /normal, charsize = 1.0, alignment = 0.5


; first window - Global
 
 plot,latitude,(field3+field4)*ymult,/noerase, linestyle = 0, thick = 2
 plot,latitude,field1*ymult,/noerase , linestyle = 1, thick = 2           
 plot,latitude,field2*ymult,/noerase, linestyle = 2 , thick = 2           
 plot,latitude,field3*ymult,/noerase, linestyle = 3 , thick = 2  
 plot,!x.crange, [0., 0.], /noerase , thick = 0.5  
 plot,[0., 0.],!y.crange,  /noerase , thick = 0.5, title = 'global'
 plot,!x.crange,!y.crange,/nodata

; 2nd window - Atlantic
 plot,latitude(index),(field7+field8)(index)*ymult,/noerase, linestyle = 0, thick = 2
 plot,latitude(index),field5(index)*ymult,/noerase , linestyle = 1, thick = 2            
 plot,latitude(index),field6(index)*ymult,/noerase, linestyle = 2 , thick = 2              
 plot,latitude(index),field7(index)*ymult,/noerase, linestyle = 3 , thick = 2              
 plot,!x.crange, [0., 0.], /noerase , thick = 0.5  
 plot,[0., 0.],!y.crange,  /noerase , thick = 0.5 , title = 'atlantic' 
 plot,!x.crange,!y.crange,/nodata

; 3rd window - Indopac
 indo1 = (field3+field4-field7-field8)
 indo2 = (field1-field5)
 indo3 = (field2-field6)
 indo4 = (field3-field7)
 plot,latitude(index),indo1(index)*ymult,/noerase, linestyle = 0, thick = 2
 plot,latitude(index),indo2(index)*ymult,/noerase , linestyle = 1, thick = 2            
 plot,latitude(index),indo3(index)*ymult,/noerase, linestyle = 2 , thick = 2              
 plot,latitude(index),indo4(index)*ymult,/noerase, linestyle = 3 , thick = 2              
 plot,!x.crange, [0., 0.], /noerase , thick = 0.5  
 plot,[0., 0.],!y.crange,  /noerase , thick = 0.5 , title = 'indopac'  
 plot,!x.crange,!y.crange,/nodata

; legend box (to do)
xyouts, 0.75, 0.35,'_________', /normal, alignment = 0.5
xyouts, 0.85, 0.35,'Total      ',/normal, alignment = 0.5
xyouts, 0.75, 0.30,'__ _ __ _ _', /normal, alignment = 0.5
xyouts, 0.86, 0.30,'Diffusive  ',/normal, alignment = 0.5
xyouts, 0.75, 0.25,'_ _ _ _ _ _ _', /normal, alignment = 0.5
xyouts, 0.85, 0.25,'Gyre       ',/normal, alignment = 0.5
xyouts, 0.75, 0.20,'................', /normal, alignment = 0.5
xyouts, 0.87, 0.20,'Overturning',/normal, alignment = 0.5

; close ps
IF keyword_set(ps) THEN BEGIN
   iodir = out_ps
   closeps 
ENDIF 

END 
